@@ -118,12 +118,12 @@ def interactive_loop(
         command_sequences = RewindableList(cli_parser.get_sequences())
         logging.info("Command sequences = {}".format(command_sequences))
 
-        # The command_sequence list can change, so we use pop() until the
+        # The command_sequence list can change, so we use pop_next() until the
         # list is exhausted
         while True:
             try:
                 command = command_sequences.pop_next()
-                logging.info("Current command = '{}'".format(command))
+                logging.info("Current command = {}".format(command))
             except IndexError:
                 break
 
@@ -223,15 +223,16 @@ def interactive_loop(
                 continue
 
             if command_lower == "push":
-                if pushed == True:
-                    print("Active speaker already pushed ... ignored")
+                if pushed is True:
+                    logging.info("Active speaker already pushed ... ignored")
                     continue
-                pushed = True
                 if speaker:
+                    pushed = True
                     logging.info(
                         "Pushing current active speaker: {}".format(speaker.player_name)
                     )
                 else:
+                    pushed = False
                     logging.info("No active speaker to push")
                 saved_speaker = speaker
                 speaker_name = None
@@ -239,8 +240,8 @@ def interactive_loop(
                 continue
 
             if command_lower == "pop":
-                if pushed == False:
-                    print("No active speaker state to pop ... ignored")
+                if pushed is False:
+                    logging.info("No active speaker state to pop ... ignored")
                     continue
                 logging.info("Popping the saved speaker state")
                 if saved_speaker:
@@ -603,22 +604,27 @@ class AliasProcessor:
                 ]
 
             # Recurse if the sequence is itself an alias
-            if sequence[0] in am.alias_names():
-                logging.info("Recursively unpacking the alias '{}'".format(sequence[0]))
-                logging.info("Unpacking: '{}'".format(sequence + alias_parms_local))
-                if self.process(sequence + alias_parms_local, am, command_list):
-                    index = command_list.index()
-                else:
-                    return False
+            try:
+                if sequence[0] in am.alias_names():
+                    logging.info("Recursively unpacking the alias '{}'".format(sequence[0]))
+                    logging.info("Unpacking: '{}'".format(sequence + alias_parms_local))
+                    if self.process(sequence + alias_parms_local, am, command_list):
+                        index = command_list.index()
+                    else:
+                        return False
 
-            # Not an alias, so insert the sequence in the command list
-            # at the correct index, and increment the index
-            else:
-                logging.info("Inserting new sequence {} at {}".format(sequence, index))
-                command_list.insert(index, sequence)
-                index += 1
-                self._command_count += 1
-                self._index = index
+                # Not an alias, so insert the sequence in the command list
+                # at the correct index, and increment the index
+                else:
+                    logging.info("Inserting new sequence {} at {}".format(sequence, index))
+                    command_list.insert(index, sequence)
+                    index += 1
+                    self._command_count += 1
+                    self._index = index
+
+            except IndexError:
+                logging.info("Empty sequence ... returning")
+                return False
 
         self._recurse_level -= 1
 
